==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/circles/l10n/ka_GE.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "წრეები",
    "Circles' files" : "წრეების ფაილები",
    "Select circles to filter by" : "ფილტრაციისთვის აირჩიეთ წრეები",
    "No circles found" : "წრეები ვერ იქნა ნაპოვნი",
    "Please select circles to filter by" : "გთხოვთ ფილტრაციისთვის აირჩიოთ წრეები",
    "No files found for the selected circles" : "არჩეული წრისთვის ფაილები ვერ იქნა ნაპოვნი",
    "You created the circle {circle}" : "თქვენ შექმენით წრე {circle}",
    "{author} created the circle {circle}" : "{author} მომხმარებელმა შექმნა წრე {circle}",
    "You deleted {circle}" : "თქვენ წაშალეთ {circle}",
    "{author} deleted {circle}" : "{author} მომხმარებელმა წაშალა {circle}",
    "You linked {group} to {circle}" : "თქვენ ჯგუფი {group} დაუკავშირეთ წრეს {circle}",
    "{group} has been linked to {circle} by {author}" : "{author} მომხმარებელმა ჯგუფი {group} დაუკავშირა წრეს {circle}",
    "You unlinked {group} from {circle}" : "თქვენ გააუქმეთ {group} ჯგუფის კავშირი წრესთან {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{author} მომხმარებელმა გააუქმა {group} ჯგუფის კავშირი წრესთან {circle}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "თქვენ დაკავშირებული {group} ჯგუფის დონე {cirlce} წრეში შეცვალეთ მნიშვნელობაზე %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} მომხმარებელმა დაკავშირებული {group} ჯგუფის დონე {circle} წრეში შეცვალა მნიშვნელობაზე %1$s",
    "You sent a request to link {circle} with {remote}" : "თქვენ გაგზავნეთ მოთხოვნა {circle} წრის {remote} დისტანციასთან დასაკავშირებლად",
    "{author} sent a request to link {circle} with {remote}" : "{author} მომხმარებელმა გამოგზავნა მოთხოვნა {circle} წრის {remote} დისტანციასთან დასაკავშირებლად",
    "{remote} requested a link with {circle}" : "{remote} დისტანციამ მოითხოვა {circle} წრესთან დაკავშირება",
    "The request to link {circle} with {remote} has been rejected" : "უარყოფილ იქნა მოთხოვნა დაკავშირდეს {circle} და {remote}",
    "The request to link {remote} with {circle} has been canceled remotely" : "მოთხოვნა დაკავშირდეს {remote} და {circle} უარყოფილ იქნა დისტანციურად",
    "The request to link {circle} with {remote} has been accepted" : "მიღებულ იქნა მოთოვნა დაკავშირდეს {circle} და {remote}",
    "You dismissed the request to link {remote} with {circle}" : "თქვენ უარყავით მოთხოვნა დაკავშირდეს {remote} და {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} მომხმარებელმა უარყო მოთხოვნა დაკავშირდეს {remote} და {circle}",
    "You canceled the request to link {circle} with {remote}" : "თქვენ უარყავით მოთხოვნა დაკავშირდეს {cirlce} და {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} მომხმარებელმა უარყო მოთხოვნა დაკავშირდეს {circle} და {remote}",
    "You accepted the request to link {remote} with {circle}" : "თქვენ მიიღეთ მოთხოვნა დაკავშირდეს {remote} და {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} მომხმარებელმა მიიღო მოთხოვნა დაკავშირდეს {remote} და {circle}",
    "A link between {circle} and {remote} is now up and running" : "კავშირი {circle} წერსა და {remote} დისტანციას შორის შემდგარია და ქმედებაშია",
    "The link between {circle} and {remote} has been shutdown remotely" : "კავშირი {circle} წრესა და {remote} დისტანციას შორის დისტანციურად გაითიშა",
    "You closed the link between {circle} and {remote}" : "თქვენ დახურეთ კავშირი {circle} წრესა და {remote} დისტანციას შორის",
    "{author} closed the link between {circle} and {remote}" : "{author} მომხმარებელმა დახურა კავშირი {circle} წრესა და {remote} დისტანციას შორის",
    "You joined {circle}" : "თქვენ შეუერთიდ წრეს {circle}",
    "{member} joined {circle}" : "{member} შეუერთდა წრეს {circle}",
    "You accepted the invitation to join {circle}" : "თქვენ მიიღეთ მოწვევა შეუერთდეთ {circle} წრეს",
    "{member} accepted the invitation to join {circle}" : "{member} მომხმარებელმა მიიღო მოწვევა შეუერთდეს {circle} წრეს",
    "You added {member} as member to {circle}" : "თქვენ მომხმარებელი {member} გააწევრიანეთ წრეში {circle}",
    "You have been added as member to {circle} by {author}" : "თქვენ {author} მომხმარებელმა გაგაწევრიანათ წრეში {circle}",
    "{member} has been added as member to {circle} by {author}" : "{member} წრეში {circle} გაწევრიანდა {author} მომხმარებლის მიერ",
    "You added {external} to {circle}" : "თქვენ დაამატეთ {external} წრეში {circle}",
    "{external} has been added to {circle} by {author}" : "{external} წრეში {circle} დაამატა მომხმარებელმა {author}",
    "You accepted {member}'s request to join {circle}" : "თქვენ მიიღეთ {member} წევრის მოთხოვნა {circle} წრეში გასაწევრიანებლად",
    "Your request to join {circle} has been accepted by {author}" : "თქვენი მოთხოვნა წრეში {circle} გაწევრიანებაზე მიიღო მომხმარებელმა {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} მომხმარებლისა მოთხოვნა გაწევრიანდეს {circle} წრეში მიღებულ იქნა {author} მომხმარებლის მიერ",
    "You left {circle}" : "თქვენ დატოვეთ {circle}",
    "{member} left {circle}" : "{member} მომხმარებელმა დატოვა {circle}",
    "You declined the invitation to join {circle}" : "თქვენ უარყავით მოწვევა გაწევრიანდეთ {circle} წრეში",
    "{member} declined an invitation to join {circle}" : "{member} მომხმარებელმა უარყო მოწვევა გაწევრიანდეს {circle} წრეში",
    "You cancelled your request to join {circle}" : "თქვენ გააუქმეთ მოთხოვნა გაწევრიანდეთ {circle} წრეში",
    "{member} cancelled his request to join {circle}" : "{member} მომხმარებელმა გააუქმა მოთხოვნა გაწევრიანდეს {circle} წრეში",
    "You removed {member} from {circle}" : "თქვენ ამოშალეთ {member} {circle} წრიდან",
    "You have been removed from {circle} by {author}" : "თქვენ {author} მომხმარებელმა {circle} წრიდან ამოგშალათ",
    "{member} has been removed from {circle} by {author}" : "{member} მომხმარებელი {circle} წრიდან {author} მომხმარებელმა ამოშალა",
    "You removed {external} from {circle}" : "თქვენ {external} ამოშალეთ {circle} წრიდან",
    "{external} has been removed from {circle} by {author}" : "{author} მომხმარებელმა ამოშალა {external} წრიდან {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "თქვენ უარყავით {member} მომხმარებლის მოწვევა შეუერთდეთ {circle} წრეს",
    "Your invitation to join {circle} has been cancelled by {author}" : "მოწვევა რომ შეუერთდეთ {circle} უაყოფილ იქნა {author} მომხმარებლის მიერ",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} მომხმარებელმა უარყო {member} მომხმარებლის მოწვევა შეუერთდეს {circle} წრეს",
    "You dismissed {member}'s request to join {circle}" : "თქვენ უარყავით {member} მომხმარებლის მოთხოვნა {circle} წრეში გასაწევრიანებლად",
    "Your request to join {circle} has been dismissed by {author}" : "თქვენი მოთხოვნა შეუერთდეთ {circle} წრეს {author} მომხმარებლის მიერ უარყოფილ იქნა",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member} მომხმარებლის მოთხოვნა შეუერთდეს {circle} წრეს უარყო {author} მომხმარებელმა",
    "You invited {member} to join {circle}" : "თქვენ მოიწვიეთ {member} შეუერთდეს {circle} წრეს",
    "You have been invited to join {circle} by {author}" : "თქვენ {author} მომხმარებელმა მოგიწვიათ შეუერთდეთ {circle} წრეს",
    "{member} has been invited to join {circle} by {author}" : "{author} მომხმარებელმა მოიწვია {member} მომხამრებელი შეუერთდეს {circle} წრეს",
    "You changed {member}'s level in {circle} to %1$s" : "თქვენ {member} მომხმარებლის დონე {circle} წრეში შეცვალეთ მნიშვნელობაზე %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} მომხმარებელმა თქვენი დონე {circle} წრეში შეცვალა მნიშვნელობაზე %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} მომხმარებელმა {member} მომხმარებლის დონე {circle} წრეში შეცვალა მნიშვნელობაზე %1$s",
    "You sent a request to join {circle}" : "თქვენ გაგზვნეთ მოთხოვნა გაწევრიანდეთ {circle} წრეში",
    "{member} sent a request to join {circle}" : "{member} მომხმარებელმა გააგზვნა მოთხოვნა გაწევრიანდეს {circle} წრეში",
    "You are the new owner of {circle}" : "თქვენ ხართ {circle} წრის ახალი მფლობელი",
    "{member} is the new owner of {circle}" : "{member} ახლა {circle} წრის ახალი მფლობელია",
    "Any important event in a <strong>Circle</strong> you are moderating" : "მნიშვნელოვანი მოვლენა <strong>წრეში</strong> რომლის მოდერატორიც ხართ",
    "Personal" : "პირადი",
    "System" : "სისტემა",
    "Visible" : "ჩანს",
    "Hidden" : "უჩინარი",
    "Local" : "ლოკალური",
    "Root" : "Root",
    "Federated" : "ფედერალური",
    "Contact" : "კონტაქტი",
    "Circle" : "წრე",
    "Member" : "წევრი",
    "Moderator" : "მოდერატორი",
    "Admin" : "ადმინისტრატორი",
    "Owner" : "მფლობელი",
    "%s shared »%s« with you." : "%s მომხმარებელმა თქვენთან გააზიარა »%s«.",
    "%s on %s" : "%s %s-ზე",
    "Password to access »%s«" : "პაროლი წვდომისთვის »%s«",
    "Click the button below to open it." : "გასახსნელად დააჭირეთ ქვემოთ მყოფ ღილაკს.",
    "Open »%s«" : "გახსენით »%s«",
    "Circle not found" : "წრე ვერ იქნა ნაპოვნი",
    "A circle with that name exists" : "წრე ამ სახელით უკვე არსებობს",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "წრეების აპლიკაციას ვერ გამოიყენებთ, სანამ ადმინისტრატორი ერთი ტიპის წრის უფლებას მაინც არ დართავს",
    "This member does not exist" : "ეს წევრი არ არსებობს",
    "Federated link not found" : "ფედერალური ბმული ვერ იქნა ნაპოვნი",
    "This feature is not available for personal circles" : "ეს ფუნქცია პირადი წრეებისთვის არაა ძალაში მყოფი",
    "The circle is not federated" : "ეს წრე არაა ფედერალური",
    "You cannot join this circle" : "ამ წრეში ვერ გაწევრიანდებით",
    "This member is not a moderator" : "ეს წევრი არაა მოდერატორი",
    "Insufficient privileges" : "პრივილეგიების უკმარისობა",
    "This member is the owner of the circle" : "ეს წევრი წრის მფოლებია",
    "Level cannot be changed for this type of member" : "დონე ამ ტიპის წევრზე ვერ შეიცვლება",
    "You are already a member of this circle" : "ამ წრის წევრი უკვე ხართ",
    "You have been blocked from this circle" : "ამ წრეში დაბლოკილი ხართ",
    "Accept" : "მიღება",
    "%s" : "%s",
    "Personal Circle" : "პირადი წრე",
    "You need a specify a type of circle" : "საჭიროა წრის ტიპის მითითება",
    "This member is not the owner of the circle" : "ეს წევრი არაა წრის მფლობელი",
    "This member is not an admin of the circle" : "ეს წევრი არაა წრის ადმინისტრატორი",
    "This group does not exist" : "ჯგუფი არ არსებობს",
    "This group is already linked to the circle" : "ჯგუფი უკვე დაკავშირებულია წრესთან",
    "You cannot edit level in a personal circle" : "პირად წრეში დონეს ვერ შეცვლით",
    "Group cannot be set as owner of a circle" : "ჯგუფი ვერ იქნება წრის მფლობელი",
    "Email format is not valid" : "ელ-ფოსტის ფორმატი არაა სწორი",
    "This contact is not available" : "კონტაქტი არაა ხელმისაწვდომი",
    "Could not find share" : "გაზიარება ვერ იქნა ნაპოვნი",
    "No files in here" : "აქ ფაილები არაა",
    "No entries found in this folder" : "ამ დირექტორიაში შენატანები ვერ იქნა ნაპოვნი",
    "Name" : "სახელი",
    "Size" : "ზომა",
    "Modified" : "შეიცვალა",
    "This user is already a member of the circle" : "მომხმარებელი უკვე არის წრის წევრი",
    "The user is already a member of this circle" : "მომხმარებელი უკვე არის წრის წევრი",
    "The user has already been invited into this circle" : "მოხმარებელი უკვე დაპატიჟებულია წრეში",
    "This user does not exist" : "მოხმარებელი არ არსებობს"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-31.0.9.tar.bz2: nextcloud/apps/circles/l10n/ka_GE.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "თქვენ წაშალეთ {circle}",
    "{author} deleted {circle}" : "{author} მომხმარებელმა წაშალა {circle}",
    "You removed {member} from {circle}" : "თქვენ ამოშალეთ {member} {circle} წრიდან",
    "You joined {circle}" : "თქვენ შეუერთიდ წრეს {circle}",
    "{member} joined {circle}" : "{member} შეუერთდა წრეს {circle}",
    "You accepted the invitation to join {circle}" : "თქვენ მიიღეთ მოწვევა შეუერთდეთ {circle} წრეს",
    "{member} accepted the invitation to join {circle}" : "{member} მომხმარებელმა მიიღო მოწვევა შეუერთდეს {circle} წრეს",
    "You added {member} as member to {circle}" : "თქვენ მომხმარებელი {member} გააწევრიანეთ წრეში {circle}",
    "You have been added as member to {circle} by {author}" : "თქვენ {author} მომხმარებელმა გაგაწევრიანათ წრეში {circle}",
    "{member} has been added as member to {circle} by {author}" : "{member} წრეში {circle} გაწევრიანდა {author} მომხმარებლის მიერ",
    "You added {external} to {circle}" : "თქვენ დაამატეთ {external} წრეში {circle}",
    "{external} has been added to {circle} by {author}" : "{external} წრეში {circle} დაამატა მომხმარებელმა {author}",
    "You accepted {member}'s request to join {circle}" : "თქვენ მიიღეთ {member} წევრის მოთხოვნა {circle} წრეში გასაწევრიანებლად",
    "Your request to join {circle} has been accepted by {author}" : "თქვენი მოთხოვნა წრეში {circle} გაწევრიანებაზე მიიღო მომხმარებელმა {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} მომხმარებლისა მოთხოვნა გაწევრიანდეს {circle} წრეში მიღებულ იქნა {author} მომხმარებლის მიერ",
    "You left {circle}" : "თქვენ დატოვეთ {circle}",
    "{member} left {circle}" : "{member} მომხმარებელმა დატოვა {circle}",
    "You declined the invitation to join {circle}" : "თქვენ უარყავით მოწვევა გაწევრიანდეთ {circle} წრეში",
    "{member} declined an invitation to join {circle}" : "{member} მომხმარებელმა უარყო მოწვევა გაწევრიანდეს {circle} წრეში",
    "You cancelled your request to join {circle}" : "თქვენ გააუქმეთ მოთხოვნა გაწევრიანდეთ {circle} წრეში",
    "You have been removed from {circle} by {author}" : "თქვენ {author} მომხმარებელმა {circle} წრიდან ამოგშალათ",
    "{member} has been removed from {circle} by {author}" : "{member} მომხმარებელი {circle} წრიდან {author} მომხმარებელმა ამოშალა",
    "You removed {external} from {circle}" : "თქვენ {external} ამოშალეთ {circle} წრიდან",
    "{external} has been removed from {circle} by {author}" : "{author} მომხმარებელმა ამოშალა {external} წრიდან {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "თქვენ უარყავით {member} მომხმარებლის მოწვევა შეუერთდეთ {circle} წრეს",
    "Your invitation to join {circle} has been cancelled by {author}" : "მოწვევა რომ შეუერთდეთ {circle} უაყოფილ იქნა {author} მომხმარებლის მიერ",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} მომხმარებელმა უარყო {member} მომხმარებლის მოწვევა შეუერთდეს {circle} წრეს",
    "You dismissed {member}'s request to join {circle}" : "თქვენ უარყავით {member} მომხმარებლის მოთხოვნა {circle} წრეში გასაწევრიანებლად",
    "Your request to join {circle} has been dismissed by {author}" : "თქვენი მოთხოვნა შეუერთდეთ {circle} წრეს {author} მომხმარებლის მიერ უარყოფილ იქნა",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member} მომხმარებლის მოთხოვნა შეუერთდეს {circle} წრეს უარყო {author} მომხმარებელმა",
    "You invited {member} to join {circle}" : "თქვენ მოიწვიეთ {member} შეუერთდეს {circle} წრეს",
    "You have been invited to join {circle} by {author}" : "თქვენ {author} მომხმარებელმა მოგიწვიათ შეუერთდეთ {circle} წრეს",
    "{member} has been invited to join {circle} by {author}" : "{author} მომხმარებელმა მოიწვია {member} მომხამრებელი შეუერთდეს {circle} წრეს",
    "You changed {member}'s level in {circle} to %1$s" : "თქვენ {member} მომხმარებლის დონე {circle} წრეში შეცვალეთ მნიშვნელობაზე %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} მომხმარებელმა თქვენი დონე {circle} წრეში შეცვალა მნიშვნელობაზე %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} მომხმარებელმა {member} მომხმარებლის დონე {circle} წრეში შეცვალა მნიშვნელობაზე %1$s",
    "You sent a request to join {circle}" : "თქვენ გაგზვნეთ მოთხოვნა გაწევრიანდეთ {circle} წრეში",
    "{member} sent a request to join {circle}" : "{member} მომხმარებელმა გააგზვნა მოთხოვნა გაწევრიანდეს {circle} წრეში",
    "You are the new owner of {circle}" : "თქვენ ხართ {circle} წრის ახალი მფლობელი",
    "{member} is the new owner of {circle}" : "{member} ახლა {circle} წრის ახალი მფლობელია",
    "Personal" : "პირადი",
    "System" : "სისტემა",
    "Visible" : "ჩანს",
    "Password protected" : "პაროლით დაცული",
    "Hidden" : "უჩინარი",
    "Local" : "ლოკალური",
    "Root" : "Root",
    "Federated" : "ფედერალური",
    "Contact" : "კონტაქტი",
    "Member" : "წევრი",
    "Moderator" : "მოდერატორი",
    "Admin" : "ადმინისტრატორი",
    "Owner" : "მფლობელი",
    "%s shared »%s« with you." : "%s მომხმარებელმა თქვენთან გააზიარა »%s«.",
    "%s on %s" : "%s %s-ზე",
    "Password to access »%s«" : "პაროლი წვდომისთვის »%s«",
    "Click the button below to open it." : "გასახსნელად დააჭირეთ ქვემოთ მყოფ ღილაკს.",
    "Open »%s«" : "გახსენით »%s«",
    "This feature is not available for personal circles" : "ეს ფუნქცია პირადი წრეებისთვის არაა ძალაში მყოფი",
    "This member is not a moderator" : "ეს წევრი არაა მოდერატორი",
    "Insufficient privileges" : "პრივილეგიების უკმარისობა",
    "This member does not exist" : "ეს წევრი არ არსებობს",
    "Level cannot be changed for this type of member" : "დონე ამ ტიპის წევრზე ვერ შეიცვლება",
    "You are already a member of this circle" : "ამ წრის წევრი უკვე ხართ",
    "You have been blocked from this circle" : "ამ წრეში დაბლოკილი ხართ",
    "Accept" : "მიღება",
    "%s" : "%s",
    "Try again" : "სცადეთ ახლიდან",
    "No files in here" : "აქ ფაილები არაა",
    "No entries found in this folder" : "ამ დირექტორიაში შენატანები ვერ იქნა ნაპოვნი",
    "Name" : "სახელი",
    "Size" : "ზომა",
    "Modified" : "შეიცვალა",
    "Shared to Circles" : "წრეებთან გაზიარებული",
    "Circle" : "წრე"
},
"nplurals=2; plural=(n!=1);");
